This is the mail archive of the gcc-patches@gcc.gnu.org mailing list for the GCC project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[patch] java: Follow spelling conventions.


Hi,

Attached is a patch to follow spelling conventions.  Committed as
obvious.

Kazu Hirata

2002-09-20  Kazu Hirata  <kazu@cs.umass.edu>

	* ChangeLog: Follow spelling conventions.
	* class.c: Likewise.
	* decl.c: Likewise.
	* expr.c: Likewise.
	* gjavah.c: Likewise.
	* java-tree.h: Likewise.
	* jcf-dump.c: Likewise.
	* jcf-parse.c: Likewise.
	* jvspec.c: Likewise.
	* lang.c: Likewise.
	* mangle.c: Likewise.
	* parse.y: Likewise.

Index: ChangeLog
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/ChangeLog,v
retrieving revision 1.1055
diff -u -r1.1055 ChangeLog
--- ChangeLog	17 Sep 2002 20:59:52 -0000	1.1055
+++ ChangeLog	21 Sep 2002 01:48:28 -0000
@@ -2830,7 +2830,7 @@
 	(generate_classfile): Compute the attribute count, invoke
 	`append_gcj_attribute'.
 	* jcf.h (typedef struct JCF): `seen_in_zip' and `java_source'
-	turned into bit fields. New bit field `right_zip.'
+	turned into bit-fields. New bit-field `right_zip.'
 	(JCF_ZERO): Set `right_zip' to zero.
 	* lang-options.h (-fforce-classes-archive-check): Added flag.
 	* lang.c (flag_force_classes_archive_check): New flag.
@@ -6912,8 +6912,8 @@
 	* jcf.h (typedef struct JCF): Field `outofsynch' deleted.
 	(jcf_out_of_synch): Prototype deleted.
 	* parse.h (struct parser_ctxt): `minus_seen', `java_error_flag',
-	`deprecated' and `class_err': integer turned into bit fields.
-	New bit fields `saved_data_ctx' and `saved_data'. Fixed comments.
+	`deprecated' and `class_err': integer turned into bit-fields.
+	New bit-fields `saved_data_ctx' and `saved_data'. Fixed comments.
 	* parse.y (package_list): New global.
 	(package_declaration:): Record newly parsed package name.
 	(extra_ctxp_pushed_p): Static global deleted.
@@ -12888,7 +12888,7 @@
 	this_wfl. Call to parse_error_context uses this_wfl instead of
 	relying on lookup_cl.
 	(parser_check_super): Comment reflects function's new returned
-	type (int). Function returns non zero value on error.
+	type (int). Function returns nonzero value on error.
 	(create_jdep_list, reverse_jdep_list, obtain_incomplete_type,
 	register_incomplete_type, jdep_resolve_class): New functions to
 	handle incomplete types in declarations.
Index: decl.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/decl.c,v
retrieving revision 1.131
diff -u -r1.131 decl.c
--- decl.c	16 Aug 2002 10:32:30 -0000	1.131
+++ decl.c	21 Sep 2002 01:48:32 -0000
@@ -57,7 +57,7 @@
 static tree check_local_unnamed_variable PARAMS ((tree, tree, tree));
 static void dump_function PARAMS ((enum tree_dump_index, tree));
 
-/* Set to non-zero value in order to emit class initilization code
+/* Set to nonzero value in order to emit class initilization code
    before static field references.  */
 extern int always_initialize_class_p;
 
Index: expr.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/expr.c,v
retrieving revision 1.150
diff -u -r1.150 expr.c
--- expr.c	16 Aug 2002 10:32:30 -0000	1.150
+++ expr.c	21 Sep 2002 01:48:35 -0000
@@ -91,7 +91,7 @@
 static GTY(()) tree ncode_ident;
 tree dtable_ident = NULL_TREE;
 
-/* Set to non-zero value in order to emit class initilization code
+/* Set to nonzero value in order to emit class initilization code
    before static field references.  */
 int always_initialize_class_p;
 
@@ -176,7 +176,7 @@
     case ABS_EXPR:
     case FLOAT_EXPR:
     case FFS_EXPR:
-      /* These don't change whether an object is non-zero or zero.  */
+      /* These don't change whether an object is nonzero or zero.  */
       return java_truthvalue_conversion (TREE_OPERAND (expr, 0));
 
     case COND_EXPR:
Index: gjavah.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/gjavah.c,v
retrieving revision 1.90
diff -u -r1.90 gjavah.c
--- gjavah.c	10 Jun 2002 03:47:36 -0000	1.90
+++ gjavah.c	21 Sep 2002 01:48:36 -0000
@@ -48,7 +48,7 @@
 /* Nonzero if we're generating JNI output.  */
 static int flag_jni = 0;
 
-/* When non zero, warn when source file is newer than matching class
+/* When nonzero, warn when source file is newer than matching class
    file.  */
 int flag_newer = 1;
 
Index: java-tree.h
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/java-tree.h,v
retrieving revision 1.155
diff -u -r1.155 java-tree.h
--- java-tree.h	16 Sep 2002 18:33:23 -0000	1.155
+++ java-tree.h	21 Sep 2002 01:48:39 -0000
@@ -160,20 +160,20 @@
 
 extern int flag_filelist_file;
 
-/* When non zero, assume all native functions are implemented with
+/* When nonzero, assume all native functions are implemented with
    JNI, not CNI.  */
 
 extern int flag_jni;
 
-/* When non zero, report the now deprecated empty statements.  */
+/* When nonzero, report the now deprecated empty statements.  */
 
 extern int flag_extraneous_semicolon;
 
-/* When non zero, always check for a non gcj generated classes archive.  */
+/* When nonzero, always check for a non gcj generated classes archive.  */
 
 extern int flag_force_classes_archive_check;
 
-/* When non zero, we emit xref strings. Values of the flag for xref
+/* When nonzero, we emit xref strings. Values of the flag for xref
    backends are defined in xref.h.  */
 
 extern int flag_emit_xref;
@@ -190,28 +190,28 @@
 extern int flag_not_overriding;
 extern int flag_static_local_jdk1_1;
 
-/* When non zero, warn when source file is newer than matching class
+/* When nonzero, warn when source file is newer than matching class
    file.  */
 extern int flag_newer;
 
-/* When non zero, call a library routine to do integer divisions. */
+/* When nonzero, call a library routine to do integer divisions. */
 extern int flag_use_divide_subroutine;
 
-/* When non zero, generate code for the Boehm GC.  */
+/* When nonzero, generate code for the Boehm GC.  */
 extern int flag_use_boehm_gc;
 
-/* When non zero, assume the runtime uses a hash table to map an
+/* When nonzero, assume the runtime uses a hash table to map an
    object to its synchronization structure.  */
 extern int flag_hash_synchronization;
 
-/* When non zero, generate checks for references to NULL.  */
+/* When nonzero, generate checks for references to NULL.  */
 extern int flag_check_references;
 
 /* Used through STATIC_CLASS_INIT_OPT_P to check whether static
    initialization optimization should be performed.  */
 extern int flag_optimize_sci;
 
-/* When non zero, use offset tables for virtual method calls
+/* When nonzero, use offset tables for virtual method calls
    in order to improve binary compatibility. */
 extern int flag_indirect_dispatch;
 
@@ -1699,7 +1699,7 @@
     TREE_SIDE_EFFECTS (WHERE) = 1;				\
   }
 
-/* Non zero if TYPE is an unchecked exception */
+/* Nonzero if TYPE is an unchecked exception */
 #define IS_UNCHECKED_EXCEPTION_P(TYPE)				\
   (inherits_from_p ((TYPE), runtime_exception_type_node)	\
    || inherits_from_p ((TYPE), error_exception_type_node))
Index: jcf-dump.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/jcf-dump.c,v
retrieving revision 1.45
diff -u -r1.45 jcf-dump.c
--- jcf-dump.c	4 Jun 2002 20:31:59 -0000	1.45
+++ jcf-dump.c	21 Sep 2002 01:48:39 -0000
@@ -71,7 +71,7 @@
 int flag_print_methods = 1;
 int flag_print_attributes = 1;
 
-/* When non zero, warn when source file is newer than matching class
+/* When nonzero, warn when source file is newer than matching class
    file.  */
 int flag_newer = 1;
 
Index: jcf-parse.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/jcf-parse.c,v
retrieving revision 1.120
diff -u -r1.120 jcf-parse.c
--- jcf-parse.c	16 Sep 2002 16:36:38 -0000	1.120
+++ jcf-parse.c	21 Sep 2002 01:48:41 -0000
@@ -68,7 +68,7 @@
 
 extern struct obstack temporary_obstack;
 
-/* Set to non-zero value in order to emit class initilization code
+/* Set to nonzero value in order to emit class initilization code
    before static field references.  */
 extern int always_initialize_class_p;
 
@@ -378,7 +378,7 @@
   return name;
 }
 
-/* Handle reading innerclass attributes. If a non zero entry (denoting
+/* Handle reading innerclass attributes. If a nonzero entry (denoting
    a non anonymous entry) is found, We augment the inner class list of
    the outer context with the newly resolved innerclass.  */
 
Index: jvspec.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/jvspec.c,v
retrieving revision 1.56
diff -u -r1.56 jvspec.c
--- jvspec.c	23 Apr 2002 22:58:09 -0000	1.56
+++ jvspec.c	21 Sep 2002 01:48:41 -0000
@@ -148,7 +148,7 @@
 {
   int i, j;
 
-  /* If non-zero, the user gave us the `-v' flag.  */ 
+  /* If nonzero, the user gave us the `-v' flag.  */
   int saw_verbose_flag = 0;
 
   int saw_save_temps = 0;
@@ -188,7 +188,7 @@
   /* The new argument list will be contained in this.  */
   const char **arglist;
 
-  /* Non-zero if we saw a `-xfoo' language specification on the
+  /* Nonzero if we saw a `-xfoo' language specification on the
      command line.  Used to avoid adding our own -xc++ if the user
      already gave a language for the file.  */
   int saw_speclang = 0;
@@ -238,10 +238,10 @@
   /* The total number of arguments with the new stuff.  */
   int num_args = 1;
 
-  /* Non-zero if linking is supposed to happen.  */
+  /* Nonzero if linking is supposed to happen.  */
   int will_link = 1;
 
-  /* Non-zero if we want to find the spec file.  */
+  /* Nonzero if we want to find the spec file.  */
   int want_spec_file = 1;
 
   /* The argument we use to specify the spec file.  */
Index: lang.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/lang.c,v
retrieving revision 1.108
diff -u -r1.108 lang.c
--- lang.c	15 Sep 2002 21:46:12 -0000	1.108
+++ lang.c	21 Sep 2002 01:48:42 -0000
@@ -126,62 +126,62 @@
 
 int flag_filelist_file = 0;
 
-/* When non zero, we emit xref strings. Values of the flag for xref
+/* When nonzero, we emit xref strings. Values of the flag for xref
    backends are defined in xref_flag_table, xref.c.  */
 
 int flag_emit_xref = 0;
 
-/* When non zero, -Wall was turned on.  */
+/* When nonzero, -Wall was turned on.  */
 int flag_wall = 0;
 
-/* When non zero, check for redundant modifier uses.  */
+/* When nonzero, check for redundant modifier uses.  */
 int flag_redundant = 0;
 
-/* When non zero, call a library routine to do integer divisions. */
+/* When nonzero, call a library routine to do integer divisions. */
 int flag_use_divide_subroutine = 1;
 
-/* When non zero, generate code for the Boehm GC.  */
+/* When nonzero, generate code for the Boehm GC.  */
 int flag_use_boehm_gc = 0;
 
-/* When non zero, assume the runtime uses a hash table to map an
+/* When nonzero, assume the runtime uses a hash table to map an
    object to its synchronization structure.  */
 int flag_hash_synchronization;
 
-/* When non zero, assume all native functions are implemented with
+/* When nonzero, assume all native functions are implemented with
    JNI, not CNI.  */
 int flag_jni = 0;
 
-/* When non zero, warn when source file is newer than matching class
+/* When nonzero, warn when source file is newer than matching class
    file.  */
 int flag_newer = 1;
 
-/* When non zero, generate checks for references to NULL.  */
+/* When nonzero, generate checks for references to NULL.  */
 int flag_check_references = 0;
 
 /* The encoding of the source file.  */
 const char *current_encoding = NULL;
 
-/* When non zero, report the now deprecated empty statements.  */
+/* When nonzero, report the now deprecated empty statements.  */
 int flag_extraneous_semicolon;
 
-/* When non zero, always check for a non gcj generated classes archive.  */
+/* When nonzero, always check for a non gcj generated classes archive.  */
 int flag_force_classes_archive_check;
 
 /* When zero, don't optimize static class initialization. This flag shouldn't
    be tested alone, use STATIC_CLASS_INITIALIZATION_OPTIMIZATION_P instead.  */
 int flag_optimize_sci = 1;
 
-/* When non zero, use offset tables for virtual method calls
+/* When nonzero, use offset tables for virtual method calls
    in order to improve binary compatibility. */
 int flag_indirect_dispatch = 0;
 
 /* When zero, don't generate runtime array store checks. */
 int flag_store_check = 1;
 
-/* When non zero, print extra version information.  */
+/* When nonzero, print extra version information.  */
 static int version_flag = 0;
 
-/* Set non-zero if the user specified -finline-functions on the command 
+/* Set nonzero if the user specified -finline-functions on the command
    line.  */
 int flag_really_inline = 0;
 
Index: parse.y
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/parse.y,v
retrieving revision 1.395
diff -u -r1.395 parse.y
--- parse.y	11 Sep 2002 19:53:14 -0000	1.395
+++ parse.y	21 Sep 2002 01:48:56 -0000
@@ -2678,7 +2678,7 @@
    Add mode documentation here. FIXME */
 
 /* Helper function. Create a new parser context. With
-   COPY_FROM_PREVIOUS set to a non zero value, content of the previous
+   COPY_FROM_PREVIOUS set to a nonzero value, content of the previous
    context is copied, otherwise, the new context is zeroed. The newly
    created context becomes the current one.  */
 
@@ -6499,7 +6499,7 @@
     abort ();
 }
 
-/* Return a non zero value if the `throws' clause of METHOD (if any)
+/* Return a nonzero value if the `throws' clause of METHOD (if any)
    is incompatible with the `throws' clause of FOUND (if any).  */
 
 static void
@@ -8238,7 +8238,7 @@
   return resolve_expression_name (access, NULL);
 }
 
-/* Return a non zero value if NODE describes an outer field inner
+/* Return a nonzero value if NODE describes an outer field inner
    access.  */
 
 static int
@@ -8274,7 +8274,7 @@
   return 0;
 }
 
-/* Return a non zero value if NODE represents an outer field inner
+/* Return a nonzero value if NODE represents an outer field inner
    access that was been already expanded. As a side effect, it returns
    the name of the field being accessed and the argument passed to the
    access function, suitable for a regeneration of the access method
@@ -10402,7 +10402,7 @@
 	     this$0 (the immediate outer context) to
 	     access$0(access$0(...(this$0))).
 
-	     maybe_use_access_method returns a non zero value if the
+	     maybe_use_access_method returns a nonzero value if the
 	     this_arg has to be moved into the (then generated) stub
 	     argument list. In the meantime, the selected function
 	     might have be replaced by a generated stub. */
@@ -10643,7 +10643,7 @@
   *mdecl = md;
   *this_arg = ta;
 
-  /* Returnin a non zero value indicates we were doing a non static
+  /* Returnin a nonzero value indicates we were doing a non static
      method invokation that is now a static invocation. It will have
      callee displace `this' to insert it in the regular argument
      list. */
@@ -12294,7 +12294,7 @@
   return node;
 }
 
-/* Complete function call's argument. Return a non zero value is an
+/* Complete function call's argument. Return a nonzero value is an
    error was found.  */
 
 static int
@@ -13136,7 +13136,7 @@
   return arg;
 }
 
-/* Return a non zero value if SOURCE can be converted into DEST using
+/* Return a nonzero value if SOURCE can be converted into DEST using
    the method invocation conversion rule (5.3).  */
 static int
 valid_method_invocation_conversion_p (dest, source)
@@ -13235,7 +13235,7 @@
 	  && TREE_OPERAND (var_acc1, 1) == TREE_OPERAND (var_acc2, 1));
 }
 
-/* Return a non zero value if CODE is one of the operators that can be
+/* Return a nonzero value if CODE is one of the operators that can be
    used in conjunction with the `=' operator in a compound assignment.  */
 
 static int
@@ -14936,7 +14936,7 @@
            BODY			 end of this labeled block)
        INCREMENT		(if any)
 
-  REVERSED, if non zero, tells that the loop condition expr comes
+  REVERSED, if nonzero, tells that the loop condition expr comes
   after the body, like in the do-while loop.
 
   To obtain a loop, the loop body structure described above is


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Index: class.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/class.c,v
retrieving revision 1.134
diff -u -r1.134 class.c
--- class.c	4 Aug 2002 22:45:30 -0000	1.134
+++ class.c	21 Sep 2002 01:48:30 -0000
@@ -75,7 +75,7 @@
   /* The class or package name.  */
   const char *ident;
 
   /* Non-zero if this represents an exclusion.  */
   int excludep;
 
   /* Pointers to other nodes in the tree.  */
@@ -141,7 +141,7 @@
 }
 
 /* Add a new IDENT to the include/exclude tree.  It's an exclusion
-   if EXCLUDEP is non-zero.  */
+   if EXCLUDEP is nonzero.  */
 
 void
 add_assume_compiled (ident, excludep)
@@ -192,7 +192,7 @@
   parent->child = node;
 }
 
 /* Returns non-zero if IDENT is the name of a class that the compiler
    should assume has been compiled to FIXME  */
 
 static int
@@ -75,7 +75,7 @@
   const char *ident;
 
-  /* Non-zero if this represents an exclusion.  */
+  /* Nonzero if this represents an exclusion.  */
   int excludep;
 
@@ -192,7 +192,7 @@
 }
 
-/* Returns non-zero if IDENT is the name of a class that the compiler
+/* Returns nonzero if IDENT is the name of a class that the compiler
    should assume has been compiled to FIXME  */
 
Index: mangle.c
===================================================================
RCS file: /cvs/gcc/gcc/gcc/java/mangle.c,v
retrieving revision 1.22
diff -u -r1.22 mangle.c
--- mangle.c	4 Jun 2002 07:10:55 -0000	1.22
+++ mangle.c	21 Sep 2002 01:48:42 -0000
@@ -170,7 +170,7 @@
 }
 
 /* This mangles a member name, like a function name or a field
-   name. Handle cases were `name' is a C++ keyword.  Return a non zero
+   name. Handle cases were `name' is a C++ keyword.  Return a nonzero
    value if unicode encoding was required.  */
 
 static void
@@ -340,7 +340,7 @@
   return match;
 }
 
 /* Mangle a record type. If a non zero value is returned, it means
    that a 'N' was emitted (so that a matching 'E' can be emitted if
    necessary.)  FOR_POINTER indicates that this element is for a pointer
    symbol, meaning it was preceded by a 'P'. */
@@ -340,7 +340,7 @@
 }
 
-/* Mangle a record type. If a non zero value is returned, it means
+/* Mangle a record type. If a nonzero value is returned, it means
    that a 'N' was emitted (so that a matching 'E' can be emitted if
    necessary.)  FOR_POINTER indicates that this element is for a pointer